
	#ifndef __PIN_H
	#define __PIN_H
	#ifndef __PIN__
	#define __PINLIB__ __declspec(dllimport)
	#else
	#define __PINLIB__ __declspec(dllexport)
	#endif
	#define BYTE unsigned char

	extern "C" 
	{
	#define FAIL						0
	#define SUCCESS						1

	//firmware error code
	#define ERR_NOT_SUPPORTED			50
	#define ERR_PARAMETER				99
	#define ERR_UNKNOWN					100
	#define ERR_INVALID_COMMAND			101
	#define ERR_COMMAND					102
	#define ERR_TIME_OUT				103
	#define ERR_UNIT_SUSPENDED			104
	#define ERR_CANCELED				105
	#define ERR_ABORTED					106
	#define ERR_KEY_TYPE				107
	#define ERR_NO_KEY					108
	#define ERR_NO_PROMPT				109
	#define ERR_CONFIG_FAIL				110
	#define ERR_CHECKVALUE_LOADED		112
	#define	ERR_LOADING_KEY_PROCESS		113
	#define ERR_MAXQ_DISCONNECTTED		115
	#define ERR_UNIT_DEACTIVE			116
	#define ERR_MAXQ_DEACTIVE			117
	#define ERR_MCU_DEACTIVE			118
	#define ERR_NO_FIRMWARE_KEY			119
	#define ERR_INVALID_SESSION_KEYTYPE	120
	#define ERR_MAXQ_SUSPEND			121
	#define ERR_DUKPT_KEY_NO_USED		122
	#define ERR_FULL_LOG				125
	#define ERR_TIME_LOADED				126
	#define ERR_ST_DEACTIVE				127
	#define ERR_ST_AND_MAXQ_DEACTIVE	128

	#define PORT_OPENED					200
	#define PORT_CLOSED					201
	#define ERR_DEVICE_BUSY				202
	#define CLEAR_TEXT_MODEL			203
	#define ERR_NO_FILE					204

	//DEVICE TYPE
	#define IBM_PINPAD					1
	#define WALMART_PINPAD				2
	#define UNKNONW_PINPAD		        3

	//Key managements
	#define KEY_DUKPT_TDES_PLAINTEXTPAN	0x01
	#define KEY_DUKPT_DES_PLAINTEXTPAN	0x02
	#define KEY_MKSK_PLAINTEXTPAN		0x03
	#define KEY_DUKPT_TDES_ENCRYPTEDPAN	0x04
	#define KEY_DUKPT_DES_ENCRYPTEDPAN	0x05
	#define KEY_MKSK_ENCRYPTEDPAN		0x06

	/*-------------------------------------
	 LED CONTROL
	--------------------------------------*/ 							
	#define LED_OFF						0x00
	#define LED_ON						0x01
	/*-------------------------------------
	 BEEPOR CONTROL
	--------------------------------------*/ 
	#define BEEP_OFF					0x00
	#define	BEEP_ON						0x01
	/*-------------------------------------
	 Device Status
	--------------------------------------*/ 
	#define DEVICE_IDLE					0x00
	#define	DEVICE_BUSY					0x01
	#define	DEVICE_TEST					0x02	
	#define DEVICE_CLOSED				0x03
	/*-------------------------------------
	KEY VALUE
	--------------------------------------*/
	#define KEY_NUM_ZERO				0x30
	#define KEY_NUM_ONE					0x31
	#define	KEY_NUM_TWO					0x32
	#define	KEY_NUM_THREE				0x33
	#define KEY_NUM_FOUR				0x34
	#define	KEY_NUM_FIVE				0x35
	#define	KEY_NUM_SIX					0x36
	#define KEY_NUM_SEVEN				0x37
	#define	KEY_NUM_EGHIT				0x38
	#define	KEY_NUM_NINE				0x39
	#define KEY_FUN_CANCEL				0x43
	#define	KEY_FUN_BACK				0x42
	#define	KEY_FUN_ENTER				0x45
	#define KEY_FUN_F1					0x45// KEY = '*'
	#define	KEY_FUN_F2					0x46// KEY = '#'
	#define	KEY_FUN_F3					0x47// KEY = '?'
	
	/***************************************************
		Com Baud
	***************************************************/
	#define BAUDRATE_2400				0x32
	#define	BAUDRATE_4800				0x33
	#define	BAUDRATE_9600				0x34	
	#define BAUDRATE_19200				0x36
	#define BAUDRATE_38400				0x37
	#define BAUDRATE_115200				0x39
	/***************************************************
		Com Parity
	***************************************************/
	#define PARITY_NONE					0x30
	#define	PARITY_ODD					0x31
	#define	PARITY_EVEN					0x32	
	/***************************************************
		Com Stop Bit
	***************************************************/
	#define STOP_BIT_ONE				0x31
	#define	STOP_BIT_TWO			    0x32	

	/***************************************************
		LCD Line
	***************************************************/
	#define LCD_TOP_LINE				0x00
	#define	LCD_BOTTOM_LINE			    0x01	
	#define LCD_BOTH_LINES				0xFF	

	typedef void (WINAPI *PKEY_FUNC)(char, LPVOID);

	__PINLIB__ BYTE WINAPI Com_OpenUSBHID();	//USB HID interface
	__PINLIB__ BYTE WINAPI Com_OpenPort(int Comport,long Baud, char Parity, int Stop, int Data);
	__PINLIB__ bool WINAPI Com_ClosePort();
	__PINLIB__ BYTE WINAPI Com_SetBaud(long Baud);
	__PINLIB__ BYTE WINAPI Com_SetParity(char Parity);
	__PINLIB__ BYTE WINAPI Com_SetStopBit(int Stopbit);
	__PINLIB__ BYTE WINAPI Com_GetBaud(char *Baud);
	__PINLIB__ BYTE WINAPI Com_GetParity(char *Parity);
	__PINLIB__ BYTE WINAPI Com_GetStopBit(char *Stopbit);
	__PINLIB__ BYTE WINAPI Sys_GetVersion(char *Version, int *Length);
	__PINLIB__ BYTE WINAPI Sys_GetModel(char *ModelNumber, int *Length);
	__PINLIB__ BYTE WINAPI Sys_Reset();
	__PINLIB__ BYTE WINAPI Sys_GetRemovalRecord(char *LogString, int *Length);
	__PINLIB__ BYTE WINAPI Sound_Control(bool Flag);
	__PINLIB__ BYTE WINAPI Sound_Tone(long Frequency, long Duration);
	__PINLIB__ BYTE WINAPI Display_LoadPrompt(int LineNum, int PromptNum);
	__PINLIB__ BYTE WINAPI Display_SavePrompt(int Num, char *Message);
	__PINLIB__ BYTE WINAPI Display_Clear(int Line);
	__PINLIB__ BYTE WINAPI BackLight_ReviewControl(bool *Flag);
	__PINLIB__ BYTE WINAPI BackLight_ReviewTimer(int *Timer);
	__PINLIB__ BYTE WINAPI BackLight_SetControl(bool Flag);
	__PINLIB__ BYTE WINAPI BackLight_SetTimer(int Timer);
	__PINLIB__ BYTE WINAPI PIN_GetPINBlock(char Key, char *AccountNumber,int Plength, char *EncryptedPIN, int *Length);
	__PINLIB__ BYTE WINAPI PIN_GetPINWithoutResponse(char Key, char *PAN,int Plength);
	__PINLIB__ BYTE WINAPI PIN_GetKey(char *EncryptedPIN, int *Length,bool *Flag);
	__PINLIB__ BYTE WINAPI PIN_GetFuncKey(char *Key, int *Length); 
	__PINLIB__ BYTE WINAPI PIN_CancelEnter();
	__PINLIB__ BYTE WINAPI PIN_SetPINLength(int Minlen, int Maxlen);
	__PINLIB__ BYTE WINAPI PIN_GetPINLength(int *Minlen, int *Maxlen);
	__PINLIB__ BYTE WINAPI GetDllVersion(char *DllVersion, int *Length);
	__PINLIB__ BYTE WINAPI PIN_GetClearText(char *ClearTextPIN, int *Length);
	__PINLIB__ BYTE WINAPI PIN_GetClearTextWithoutResponse();
	__PINLIB__ BYTE WINAPI PIN_GetNumeric(char *InputMessage,int MessageLength,char *ClearTextPIN, int *Length);
	__PINLIB__ BYTE WINAPI KEY_LoadMACKEY(char *Key,int length);
	__PINLIB__ BYTE WINAPI KEY_EncryptData(char *RawData,int *length);
	__PINLIB__ BYTE WINAPI PIN_GetAllKeyWithoutResponse();
	__PINLIB__ BYTE WINAPI PIN_GetAllKey(char *Key, int *Length, bool *Flag);
}
#endif

